from .entities import ApiKeyEntity, UserRole
from .repositories import ApiKeyRepository
from .services import ApiKeyService
from .dependencies import (
    AuthContext,
    get_auth_context,
    require_roles,
    RequireAdmin,
    RequireUser,
    RequireService,
    protected,
    protected_controller,

)
from .module import install_auth_module


__all__ = [
    "ApiKeyEntity",
    "UserRole",
    "ApiKeyRepository",
    "ApiKeyService",
    "AuthContext",
    "get_auth_context",
    "require_roles",
    "RequireAdmin",
    "RequireUser",
    "RequireService",
    "install_auth_module",
    "protected",
    "protected_controller",
]



from minix.core.auth.entities import ApiKeyEntity
from minix.core.auth.repositories import ApiKeyRepository
from minix.core.auth.services import ApiKeyService
from minix.core.registry import Registry
from minix.core.connectors.sql_connector import SqlConnector


def install_auth_module():
    sql_connector = Registry().get(SqlConnector)

    repo = ApiKeyRepository(ApiKeyEntity, sql_connector)
    Registry().register(ApiKeyRepository, repo)

    service = ApiKeyService(repo)
    Registry().register(ApiKeyService, service)
